About
=====

Zarr is a format for the storage of chunked, compressed, N-dimensional arrays
inspired by `HDF5 <https://www.hdfgroup.org/HDF5/>`_, `h5py
<https://www.h5py.org/>`_ and `bcolz <https://bcolz.readthedocs.io/>`_.

These documents describe the Zarr-Python implementation. More information
about the Zarr format can be found on the `main website <https://zarr.dev>`_.

Projects using Zarr
-------------------

If you are using Zarr-Python, we would `love to hear about it
<https://github.com/zarr-developers/community/issues/19>`_.

Funding
-------
The project is fiscally sponsored by `NumFOCUS <https://numfocus.org/>`_, a US
501(c)(3) public charity, and development is supported by the
`MRC Centre for Genomics and Global Health <https://www.cggh.org>`_
and the `Chan Zuckerberg Initiative <https://chanzuckerberg.com/>`_.

.. _NumCodecs: https://numcodecs.readthedocs.io/
